@@ -1,9 +1,8 @@
 import sys
 import re
-import numpy as np  # type: ignore
-from typing import List, Optional
-
-from uniplot.discretizer import compute_y_at_middle_of_row
+import numpy as np
+from numpy.typing import NDArray
+from typing import List
 
 UNICODE_SQUARES = {
     0: "",
@@ -40,7 +39,7 @@ COLOR_RESET_CODE = "\033[0m"
 COLOR_CODE_REGEX = re.compile(r"\033\[\d+m")
 
 
-def character_for_2by2_pixels(square: np.array, color_mode: bool = False) -> str:
+def character_for_2by2_pixels(square: NDArray, color_mode: bool = False) -> str:
     """
     Convert 2x2 matrix (non-negative integers) to unicode character representation for plotting.
     """
@@ -95,7 +94,7 @@ def plot_title(title: str, width: int) -> str:
 
 
 def erase_previous_lines(nr_lines: int) -> None:
-    for i in range(nr_lines):
+    for _ in range(nr_lines):
         sys.stdout.write(ERASE_LINE)
         sys.stdout.write(CURSOR_UP_ONE)
         sys.stdout.write(ERASE_LINE)
@@ -106,29 +105,6 @@ def erase_previous_lines(nr_lines: int) -> None:
 ###########
 
 
-def _find_shortest_string_representation(numbers: List[Optional[float]]) -> List[str]:
-    """
-    This method will find the shortest numerical values for axis labels that are different from ech other.
-    """
-    compact_abs_numbers = [abs(n) for n in numbers if n is not None]
-
-    # We actually want to add one more digit than needed for uniqueness
-    for nr_digits in range(10):
-        # The test for the right number of digits happens on the absolute numbers. See issue #5.
-        test_list = [_float_format(n, nr_digits) for n in compact_abs_numbers]
-        if len(test_list) == len(set(test_list)):
-            return ["" if n is None else _float_format(n, nr_digits) for n in numbers]
-
-    # Fallback to naive string conversion
-    return ["" if n is None else str(n) for n in numbers]
-
-
-def _float_format(n: float, nr_digits: int):
-    if nr_digits == 0:
-        return ("{:,d}").format(int(n))
-    return ("{:,." + str(nr_digits) + "f}").format(float(n))
-
-
 def _center_if_possible(text: str, width: int) -> str:
     lines = text.splitlines()
     max_len = max([len(_text_without_control_chars(line)) for line in lines])
